@@ -24,9 +24,8 @@ class connector:
 		token = json.loads(reply.text)
 		self.head = {'Authorization' : "Bearer {}".format(token['access_token'])}
 		self.url = 'https://api.intra.42.fr/v2'
-		if 'v' in kwargs:
-			self.verbose = True
-			print(self.BLUE + "Verbose activate." + self.DEFAULT)
+		self.verbose = True
+		print(self.BLUE + "Verbose activate." + self.DEFAULT)
 		print(self.GREEN + "Connector ready to use! " + self.BLUE + "(If you need some information : helper() - or thanos@42paris.fr)" + self.DEFAULT)
 
 	def helper(self):
@@ -42,7 +41,8 @@ class connector:
 		print("\t- \"get_id([login])\" -> Print id & return id for given login.")
 		print("\t- \"get_private_email([login])\" -> Print email & return email for given login.")
 		print("\t- \"change_password([login],[new_password])\" -> Change password for given login.")
-
+		print("\t- \"verbose()\" -> Activate verbose.")
+		print("\t- \"unverbose()\" -> Deactivate verbose.")
 
 	def dot_env_parser(self):
 		ret = {}
@@ -150,7 +150,7 @@ class connector:
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
 			print(self.RED + str(err) + 'on PATCH ' + url + self.DEFAULT)
-		return (json.loads(reply.text))
+		# return (json.loads(reply.text))
 
 	def delete(self, endpoint, **kwargs):
 		url = self.url + endpoint
@@ -158,10 +158,10 @@ class connector:
 			reply = requests.delete(url, headers=self.head )
 			reply.raise_for_status()
 			if self.verbose == True:
-				print(self.GREEN + "Success POST on " + url + self.DEFAULT)
+				print(self.GREEN + "Success DELETE on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
-			print(self.RED + str(err) + 'on DELETE ' + url + self.DEFAULT)
+			print(self.RED + str(err) + ' on DELETE ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
 	def build_list_email(self, all_logins):
@@ -205,3 +205,8 @@ class connector:
 		data = self.get(url)
 		return (data[0]['level'])
 
+	def verbose(self):
+		self.verbose = True
+
+	def unverbose(self):
+		self.verbose = False
